@@ -67,6 +67,14 @@ class base_store(object):
         Iterates over all the keys in the store
         '''
 
+    @abstractmethod
+    def listlocks(self):
+        '''
+        for key in store.listlocks():
+            ...
+
+        Iterates over all the locks in the store
+        '''
 
     @abstractmethod
     def can_load(self, name):
@@ -263,3 +271,31 @@ class base_lock(object):
         locked : boolean
         '''
 
+    @abstractmethod
+    def fail(self):
+        '''
+        lock.fail()
+
+        Mark a task as failed.
+        Should have no effect if the task isn't locked
+
+        Returns
+        -------
+        failed : bool
+            Whether the task was marked as failed
+        '''
+
+    @abstractmethod
+    def is_failed(self):
+        '''
+        failed = lock.is_failed()
+
+        Returns whether this task is marked as failed.
+
+        This code is not race-condition free. It may happen that by the time
+        this function returns, the failed lock has been released.
+
+        Returns
+        -------
+        failed : boolean
+        '''
