@@ -93,7 +93,7 @@ tricky to support since the general code relies on the function name)''')
 
     def run(self, force=False, save=True, debug_mode=False):
         '''
-        task.run(force=False, save=True)
+        task.run(force=False, save=True, debug_mode=False)
 
         Performs the task.
 
@@ -105,6 +105,12 @@ tricky to support since the general code relies on the function name)''')
         save : boolean, optional
             if true, save the result to the store
             (default: True)
+        debug_mode : boolean, optional
+            whether to run in debug mode (adds extra checks)
+
+        Returns
+        -------
+        val : return value from Task
         '''
         assert self.can_run()
         if debug_mode: self._check_hash()
@@ -281,7 +287,7 @@ tricky to support since the general code relies on the function name)''')
 
     def __repr__(self):
         '''Detailed representation'''
-        return 'Task(%s, args=%s, kwargs=%s)' % (self.name, self.args, self.kwargs)
+        return 'Task({}, args={}, kwargs={})'.format(self.name, self.args, self.kwargs)
 
     def lock(self):
         '''
@@ -341,6 +347,35 @@ tricky to support since the general code relies on the function name)''')
             self._lock = self.store.getlock(self.hash())
         return self._lock.is_locked()
 
+    def fail(self):
+        '''
+        task.fail()
+
+        Marks the task as failed
+
+        If the lock was not held, and exception will be raised
+        '''
+        return self._lock.fail()
+
+    def is_failed(self):
+        '''
+        is_failed = t.is_failed()
+
+        Returns
+        -------
+        is_failed : boolean
+            Whether the task is in failed state.
+
+        See Also
+        --------
+        lock : create lock
+        unlock : destroy lock
+        '''
+        if not hasattr(self, '_lock'):
+            self._lock = self.store.getlock(self.hash())
+        return self._lock.is_failed()
+
+
 class Tasklet(TaskletMixin):
     '''
     Tasklet
